# **IL5pred**
A computational method to predict and scan IL-5 inducing peptides.
## Introduction
IL5pred is developed to predict, scan, and design IL-5 inducing peptides. In the standalone version, Random-Forest based model is implemented along with the BLAST search, named as a hybrid approach.
It is also available as a web server at https://webs.iiitd.edu.in/raghava/il5pred. Please read/cite the content about the IL5pred for complete information including the algorithm behind the approach.

## Standalone
The Standalone version of IL5pred is written in python3 and the following libraries are necessary for a successful run:
- scikit-learn
- Pandas
- Numpy
- blastp

## Minimum USAGE
To know about the available option for the standalone, type the following command:
```
python il5pred.py -h
```
To run the example, type the following command:
```
python3 il5pred.py -i example_input.fa
```
This will predict if the submitted sequences are IL-5 inducers or Non-inducers. It will use other parameters by default. It will save the output in "outfile.csv" in CSV (comma-separated variables).

## Full Usage
```
usage: il5pred.py [-h] 
                       [-i INPUT 
                       [-o OUTPUT]
		       [-j {1,2,3}]
		       [-t THRESHOLD]
                       [-w {9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25}]
		       [-d {1,2}]
```
```
Please provide the following arguments for a successful run

optional arguments:
  -h, --help            show this help message and exit
  -i INPUT, --input INPUT
                        Input: protein or peptide sequence(s) in FASTA format
                        or single sequence per line in a single letter code
  -o OUTPUT, --output OUTPUT
                        Output: File for saving results by default outfile.csv
  -j {1,2,3}, --job {1,2,3}
                        Job Type: 1:Predict, 2: Design, 3:Scan, by default 1
  -t THRESHOLD, --threshold THRESHOLD
                        Threshold: Value between 0 to 1 by default 0.21
  -w {9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25}, --winleng {9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25}
                        Window Length: 9 to 20 (scan mode only), by default 9
  -d {1,2}, --display {1,2}
                        Display: 1:IL-5 inducing peptides only, 2: All peptides, by default 1
```

**Input File:** It allows users to provide input in FASTA format.

**Output File:** Program will save the results in CSV format, in case the user does not provide the output file name, it will be stored in "outfile.csv".

**Threshold:** User should provide a threshold between 0 and 1, by default it's 0.21.

**Job:** User is allowed to choose between three different modules, such as 1 for prediction, 2 for designing and 3 for scanning, by default it's 1.

**Window length**: The user can choose any pattern length between 9 and 25 in long sequences. This option is available for only the scanning module.

**Display type:** This option allow users to fetch either only IL-5 inducing peptides by choosing option 1 or prediction against all peptides by choosing option 2.

IL5pred Package Files
=======================
It contains the following files, brief description of these files are given below

INSTALLATION                    : Installation instructions

LICENSE                         : License information

README.md                       : This file provides information about this package

model.zip                       : This zipped file contains the compressed version of the model

envfile                         : This file comprises paths for the database and blastp executable

il5pred.py                      : Main python program

example_input.fa                : Example file contains peptide sequences in FASTA format

example_predict_output.csv      : Example output file for predict module

example_proteinscan_output.csv  : Example output file for protein scan module

example_design_output.csv       : Example output file for design module
